@@ -32,7 +32,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include "eog-dialog.h"
 #include "eog-image.h"
 #include "eog-metadata-sidebar.h"
 #include "eog-properties-dialog.h"
@@ -441,7 +440,7 @@ static void
 _details_button_clicked_cb (GtkButton *button, gpointer user_data)
 {
 	EogMetadataSidebarPrivate *priv = EOG_METADATA_SIDEBAR(user_data)->priv;
-	EogDialog *dlg;
+	GtkWidget *dlg;
 
 	g_return_if_fail (priv->parent_window != NULL);
 
@@ -450,7 +449,7 @@ _details_button_clicked_cb (GtkButton *button, gpointer user_data)
 	g_return_if_fail (dlg != NULL);
 	eog_properties_dialog_set_page (EOG_PROPERTIES_DIALOG (dlg),
 					EOG_PROPERTIES_DIALOG_PAGE_DETAILS);
-	eog_dialog_show (dlg);
+	gtk_widget_show (dlg);
 }
 #endif
 
